MultiSplitView class

A widget to provides horizontal or vertical multiple split view.

Inheritance

Constructors

MultiSplitView({Key? key, Axis axis = MultiSplitView.defaultAxis, required List<Widget> children, MultiSplitViewController? controller, DividerBuilder? dividerBuilder, OnWeightChange? onWeightChange, DividerTapCallback? onDividerTap, DividerTapCallback? onDividerDoubleTap, bool resizable = true, bool antiAliasingWorkaround = true, List<Area>? initialAreas})
Creates an MultiSplitView.

Properties

antiAliasingWorkaround → bool
Enables a workaround for https://github.com/flutter/flutter/issues/14288
final
axis → Axis
final
children → List<Widget>
final
controller → MultiSplitViewController?
final
dividerBuilder → DividerBuilder?
Defines a builder of dividers. Overrides the default divider created by the theme.
final
hashCode → int
The hash code for this object.
no setterinherited
initialAreas → List<Area>?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDividerDoubleTap → DividerTapCallback?
Signature for when a divider double tap has occurred.
final
onDividerTap → DividerTapCallback?
Signature for when a divider tap has occurred.
final
onWeightChange → OnWeightChange?
Function to listen children weight change. The listener will run on the parent's resize or on the dragging end of the divisor.
final
resizable → bool
Indicates whether it is resizable. The default value is TRUE.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultAxis → const Axis