TabbedViewMenuThemeData class

Theme for menu.

Constructors

TabbedViewMenuThemeData({EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? menuItemPadding, TextStyle? textStyle = const TextStyle(fontSize: 13), Border? border, Color? color, bool blur = true, bool ellipsisOverflowText = false, double dividerThickness = 0, double maxWidth = 200, Color? dividerColor, Color? hoverColor})

Properties

blur ↔ bool
Indicates whether to apply a blur effect on the content.
getter/setter pair
border ↔ Border?
getter/setter pair
color ↔ Color?
getter/setter pair
dividerColor ↔ Color?
getter/setter pair
dividerThickness ↔ double
getter/setter pair
ellipsisOverflowText ↔ bool
Use an ellipsis to indicate that the text has overflowed.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
hoverColor ↔ Color?
getter/setter pair
margin ↔ EdgeInsetsGeometry?
getter/setter pair
maxWidth ↔ double
getter/setter pair
Empty space to inscribe inside the buttonsAreaDecoration. The menu item, if any, is placed inside this padding.
getter/setter pair
padding ↔ EdgeInsetsGeometry?
Empty space to inscribe inside the buttonsAreaDecoration. The menu area, if any, is placed inside this padding.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle ↔ TextStyle?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override